Decoding and Encoding of TIFF Images, specifically made extensible, well-tested an asynchronous (for COGs)
TIFF (Tagged Image File Format) is a versatile image format that supports lossless and lossy compression.
Related Links
- https://web.archive.org/web/20210108073850/https://www.adobe.io/open/standards/TIFF.html - The TIFF specification
- https://download.osgeo.org/libtiff/doc/TIFF6.pdf - Tiff spec as PDF
Modules
- bytecast
- for byte casting. Not sure if we can actually stomp in bytemuck as dependency.
- decoder
- static decoding functions to be used with the Tiff/Image struct. Additionally an opinionated decoder, optimized for COGs (without the geo part).
- encoder
- static encoding functions to be used with Tiff/Image struct. Additionally, opinionated COG-building encoder
- error
- Errors
- structs
- util
- Generic utility functions that can be used for both decoding and encoding